@@ -1,4 +1,4 @@
-/* $Id: delim-import-widget.h,v 1.1 2000/04/07 18:30:32 trow Exp $ */
+/* $Id: delim-import-widget.h,v 1.4 2000/10/27 18:22:43 trow Exp $ */
 
 /*
  * delim-import-widget.h
@@ -27,14 +27,16 @@
 #ifndef _INC_DELIM_IMPORT_WIDGET_H
 #define _INC_DELIM_IMPORT_WIDGET_H
 
-#include <config.h>
 #include <gnome.h>
+#include <guppi-defs.h>
 #include "guppi-delimited-importer.h"
 
-GtkWidget* guppi_delimited_importer_widget(GuppiDelimitedImporter*);
+BEGIN_GUPPI_DECLS
 
+GtkWidget *guppi_delimited_importer_widget (GuppiDelimitedImporter *);
 
+END_GUPPI_DECLS
 
 #endif /* _INC_DELIM_IMPORT-WIDGET_H */
 
-/* $Id: delim-import-widget.h,v 1.1 2000/04/07 18:30:32 trow Exp $ */
+/* $Id: delim-import-widget.h,v 1.4 2000/10/27 18:22:43 trow Exp $ */
