@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-item.h,v 1.2 2000/04/25 13:57:13 trow Exp $ */
+/* $Id: guppi-axis-item.h,v 1.7 2000/10/27 18:22:44 trow Exp $ */
 
 /*
  * guppi-axis-item.h
@@ -28,10 +28,12 @@
 #ifndef _INC_GUPPI_AXIS_ITEM_H
 #define _INC_GUPPI_AXIS_ITEM_H
 
-#include <config.h>
 #include <gnome.h>
-
+#include <guppi-defs.h>
 #include <guppi-canvas-item.h>
+#include <guppi-raster-text.h>
+
+BEGIN_GUPPI_DECLS
 
 typedef struct _GuppiAxisItem GuppiAxisItem;
 typedef struct _GuppiAxisItemClass GuppiAxisItemClass;
@@ -39,7 +41,8 @@ typedef struct _GuppiAxisItemClass GuppiAxisItemClass;
 struct _GuppiAxisItem {
   GuppiCanvasItem parent;
 
-  GList* label_list;
+  GList *label_list;
+  GuppiRasterText *legend_text;
 };
 
 struct _GuppiAxisItemClass {
@@ -54,8 +57,10 @@ struct _GuppiAxisItemClass {
 #define GUPPI_IS_AXIS_ITEM0(obj) (((obj) == NULL) || (GUPPI_IS_AXIS_ITEM(obj)))
 #define GUPPI_IS_AXIS_ITEM_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_AXIS_ITEM))
 
-GtkType guppi_axis_item_get_type(void);
+GtkType guppi_axis_item_get_type (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_AXIS_ITEM_H */
 
-/* $Id: guppi-axis-item.h,v 1.2 2000/04/25 13:57:13 trow Exp $ */
+/* $Id: guppi-axis-item.h,v 1.7 2000/10/27 18:22:44 trow Exp $ */
