@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-tools.h,v 1.1 2000/04/07 18:32:42 trow Exp $ */
+/* $Id: guppi-scatter-tools.h,v 1.8 2000/10/27 18:22:49 trow Exp $ */
 
 /*
  * guppi-scatter-tools.h
@@ -27,17 +27,23 @@
 #ifndef _INC_GUPPI_SCATTER_TOOLS_H
 #define _INC_GUPPI_SCATTER_TOOLS_H
 
-#include <config.h>
 #include <gnome.h>
-
 #include <guppi-plot-tool.h>
+#include <guppi-plot-toolkit.h>
+#include <guppi-defs.h>
 
-GuppiPlotTool* guppi_scatter_tool_radius_brush(gint brush, double radius);
-GuppiPlotTool* guppi_scatter_tool_frame_brush(gint brush);
-GuppiPlotTool* guppi_scatter_tool_home_view(void);
+BEGIN_GUPPI_DECLS
 
-GuppiPlotTool* guppi_scatter_tool_drag_point(void);
+GuppiPlotTool *guppi_scatter_tool_radius_brush (gint brush, double radius);
+GuppiPlotTool *guppi_scatter_tool_frame_brush (gint brush);
+GuppiPlotTool *guppi_scatter_tool_drag_point (void);
+
+GuppiPlotToolkit *guppi_scatter_toolkit_default (void);
+GuppiPlotToolkit *guppi_scatter_toolkit_drag (void);
+GuppiPlotToolkit *guppi_scatter_toolkit_brush (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SCATTER-TOOLS_H */
 
-/* $Id: guppi-scatter-tools.h,v 1.1 2000/04/07 18:32:42 trow Exp $ */
+/* $Id: guppi-scatter-tools.h,v 1.8 2000/10/27 18:22:49 trow Exp $ */
