@@ -1,4 +1,4 @@
-/* $Id: guppi-slinreg-statviewer.h,v 1.1 2000/04/07 18:32:42 trow Exp $ */
+/* $Id: guppi-slinreg-statviewer.h,v 1.4 2000/10/27 18:22:50 trow Exp $ */
 
 /*
  * guppi-slinreg-statviewer.h
@@ -27,15 +27,16 @@
 #ifndef _INC_GUPPI_SLINREG_STATVIEWER_H
 #define _INC_GUPPI_SLINREG_STATVIEWER_H
 
-#include <config.h>
 #include <gnome.h>
-
 #include <guppi-simple-linreg.h>
+#include <guppi-defs.h>
 
-GtkWidget* guppi_slinreg_statviewer_new(GuppiSimpleLinreg* slr);
+BEGIN_GUPPI_DECLS
 
+GtkWidget *guppi_slinreg_statviewer_new (GuppiSimpleLinreg * slr);
 
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SLINREG-STATVIEWER_H */
 
-/* $Id: guppi-slinreg-statviewer.h,v 1.1 2000/04/07 18:32:42 trow Exp $ */
+/* $Id: guppi-slinreg-statviewer.h,v 1.4 2000/10/27 18:22:50 trow Exp $ */
