@@ -1,4 +1,4 @@
-/* $Id: app_scm.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: app_scm.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
 
 /*
  * app_scm.h
@@ -27,11 +27,17 @@
 #ifndef _INC_APP_SCM_H
 #define _INC_APP_SCM_H
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
+
 /* Registers scheme bindings for controlling application-level features
    of guppi, like UI elements. */
-void guppi_app_scm_init(void);
+void guppi_app_scm_init (void);
+
+END_GUPPI_DECLS
 
 
 #endif /* _INC_APP_SCM_H */
 
-/* $Id: app_scm.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: app_scm.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
