@@ -1,4 +1,4 @@
-/* $Id: file-open.h,v 1.3 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: file-open.h,v 1.5 2000/10/27 18:22:56 trow Exp $ */
 
 /*
  * file-open.h
@@ -29,19 +29,21 @@
 
 #include <config.h>
 #include <gnome.h>
-
+#include <guppi-defs.h>
 #include "guppi-app.h"
 
-void file_open(GtkWidget*, GuppiApp*);
+BEGIN_GUPPI_DECLS
+
+void file_open (GtkWidget *, GuppiApp *);
 
 #define DEFAULT_FILE_OPEN_THRESHOLD 0.0
 
-void file_open_ask_about_import_type(const gchar* filename,
-				     gboolean force_ask,
-				     double threshold,
-				     GuppiApp*);
+void file_open_ask_about_import_type (const gchar * filename,
+				      gboolean force_ask,
+				      double threshold, GuppiApp *);
 
+END_GUPPI_DECLS
 
 #endif /* _INC_FILE_OPEN_H */
 
-/* $Id: file-open.h,v 1.3 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: file-open.h,v 1.5 2000/10/27 18:22:56 trow Exp $ */
