@@ -1,4 +1,4 @@
-/* $Id: guile-load.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: guile-load.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
 
 /*
  * guile-load.h
@@ -27,10 +27,17 @@
 #ifndef _INC_GUILE_LOAD_H
 #define _INC_GUILE_LOAD_H
 
-void guile_select_and_load(GnomeApp*);
-void guile_load(GnomeApp*, const gchar* filename);
-void guile_load_add_recent(GnomeApp* app, const gchar* filename);
+#include <gnome.h>
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
+
+void guile_select_and_load (GnomeApp *);
+void guile_load (GnomeApp *, const gchar * filename);
+void guile_load_add_recent (GnomeApp * app, const gchar * filename);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUILE_LOAD_H */
 
-/* $Id: guile-load.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: guile-load.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
