@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-app.h,v 1.2 2000/04/21 23:22:42 trow Exp $ */
+/* $Id: guppi-app.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
 
 /*
  * guppi-app.h
@@ -30,6 +30,9 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
 
 typedef struct _GuppiApp GuppiApp;
 typedef struct _GuppiAppClass GuppiAppClass;
@@ -40,8 +43,8 @@ typedef struct _RecentFile RecentFile;
 struct _GuppiApp {
   GnomeApp parent;
 
-  gchar* most_recent_open_directory;
-  RecentFile* recent_file[RECENT_FILE_MAX];
+  gchar *most_recent_open_directory;
+  RecentFile *recent_file[RECENT_FILE_MAX];
 };
 
 struct _GuppiAppClass {
@@ -56,13 +59,15 @@ struct _GuppiAppClass {
 #define GUPPI_IS_APP0(obj) (((obj) == NULL) || (GUPPI_IS_APP(obj)))
 #define GUPPI_IS_APP_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_APP))
 
-GtkType guppi_app_get_type(void);
+GtkType guppi_app_get_type (void);
 
-GtkWidget* guppi_app_new(void);
+GtkWidget *guppi_app_new (void);
 
-void guppi_app_add_recently_visited_file(GuppiApp* app, const gchar* filename);
+void guppi_app_add_recently_visited_file (GuppiApp * app,
+					  const gchar * filename);
 
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_APP_H */
 
-/* $Id: guppi-app.h,v 1.2 2000/04/21 23:22:42 trow Exp $ */
+/* $Id: guppi-app.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
