@@ -1,4 +1,4 @@
-/* $Id: term.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: term.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
 
 /*
  * term.h
@@ -27,10 +27,15 @@
 #ifndef _INC_TERM_H
 #define _INC_TERM_H
 
-void guile_terminal(void);
-void close_guile_terminal(void);
+#include <guppi-defs.h>
 
+BEGIN_GUPPI_DECLS
+
+void guile_terminal (void);
+void close_guile_terminal (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_TERM_H */
 
-/* $Id: term.h,v 1.2 2000/04/13 19:45:18 trow Exp $ */
+/* $Id: term.h,v 1.4 2000/10/27 18:22:56 trow Exp $ */
