@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-array-impl.c,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-array-impl.c,v 1.5 2000/12/14 20:23:04 trow Exp $ */
 
 /*
  * guppi-array-impl.c
@@ -25,16 +25,18 @@
  * USA
  */
 
+#include <config.h>
+#include <guppi-memory.h>
 #include "guppi-array-impl.h"
 
-static GtkObjectClass* parent_class = NULL;
+static GtkObjectClass *parent_class = NULL;
 
 enum {
   ARG_0
 };
 
 static void
-guppi_array_impl_get_arg(GtkObject* obj, GtkArg* arg, guint arg_id)
+guppi_array_impl_get_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
 {
   switch (arg_id) {
 
@@ -44,7 +46,7 @@ guppi_array_impl_get_arg(GtkObject* obj, GtkArg* arg, guint arg_id)
 }
 
 static void
-guppi_array_impl_set_arg(GtkObject* obj, GtkArg* arg, guint arg_id)
+guppi_array_impl_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
 {
   switch (arg_id) {
 
@@ -54,27 +56,27 @@ guppi_array_impl_set_arg(GtkObject* obj, GtkArg* arg, guint arg_id)
 }
 
 static void
-guppi_array_impl_destroy(GtkObject* obj)
+guppi_array_impl_destroy (GtkObject * obj)
 {
   if (parent_class->destroy)
-    parent_class->destroy(obj);
+    parent_class->destroy (obj);
 }
 
 static void
-guppi_array_impl_finalize(GtkObject* obj)
+guppi_array_impl_finalize (GtkObject * obj)
 {
   if (parent_class->finalize)
-    parent_class->finalize(obj);
+    parent_class->finalize (obj);
 }
 
 static void
-guppi_array_impl_class_init(GuppiArrayImplClass* klass)
+guppi_array_impl_class_init (GuppiArrayImplClass * klass)
 {
-  GtkObjectClass* object_class = (GtkObjectClass*)klass;
+  GtkObjectClass *object_class = (GtkObjectClass *) klass;
 
-  parent_class = gtk_type_class(GUPPI_TYPE_DATA_IMPL);
+  parent_class = gtk_type_class (GUPPI_TYPE_DATA_IMPL);
 
-  GUPPI_DATA_IMPL_CLASS(object_class)->impl_name = "-* Array Impl *-";
+  GUPPI_DATA_IMPL_CLASS (object_class)->impl_name = "-* Array Impl *-";
 
   object_class->get_arg = guppi_array_impl_get_arg;
   object_class->set_arg = guppi_array_impl_set_arg;
@@ -84,28 +86,28 @@ guppi_array_impl_class_init(GuppiArrayImplClass* klass)
 }
 
 static void
-guppi_array_impl_init(GuppiArrayImpl* obj)
+guppi_array_impl_init (GuppiArrayImpl * obj)
 {
 
 }
 
-GtkType
-guppi_array_impl_get_type(void)
+GtkType guppi_array_impl_get_type (void)
 {
   static GtkType guppi_array_impl_type = 0;
   if (!guppi_array_impl_type) {
     static const GtkTypeInfo guppi_array_impl_info = {
       "GuppiArrayImpl",
-      sizeof(GuppiArrayImpl),
-      sizeof(GuppiArrayImplClass),
-      (GtkClassInitFunc)guppi_array_impl_class_init,
-      (GtkObjectInitFunc)guppi_array_impl_init,
-      NULL, NULL, (GtkClassInitFunc)NULL
+      sizeof (GuppiArrayImpl),
+      sizeof (GuppiArrayImplClass),
+      (GtkClassInitFunc) guppi_array_impl_class_init,
+      (GtkObjectInitFunc) guppi_array_impl_init,
+      NULL, NULL, (GtkClassInitFunc) NULL
     };
-    guppi_array_impl_type = gtk_type_unique(GUPPI_TYPE_DATA_IMPL, &guppi_array_impl_info);
+    guppi_array_impl_type =
+      gtk_type_unique (GUPPI_TYPE_DATA_IMPL, &guppi_array_impl_info);
   }
   return guppi_array_impl_type;
 }
 
 
-/* $Id: guppi-array-impl.c,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-array-impl.c,v 1.5 2000/12/14 20:23:04 trow Exp $ */
