@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-array-impl.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-array-impl.h,v 1.8 2000/10/27 18:22:58 trow Exp $ */
 
 /*
  * guppi-array-impl.h
@@ -28,33 +28,35 @@
 #ifndef _INC_GUPPI_ARRAY_IMPL_H
 #define _INC_GUPPI_ARRAY_IMPL_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "guppi-data-impl.h"
 #include "guppi-array.h"
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
+
 typedef struct _GuppiArrayImpl GuppiArrayImpl;
-typedef struct _GuppiArrayImplClass GuppiArrayImplClass;
 
 struct _GuppiArrayImpl {
   GuppiDataImpl parent;
 
-  gint* dims;         /* pointer to int containing # of dimensions */
-  gint** index_min;   /* pointer^2 to intv containing min indices, by dim */
-  gint** index_sizes; /* pointer^2 to intv containing size, by dim */
-  gint** strides;     /* pointer^2 to intv of strides, by dim */
-  double** data;      /* pointer^2 pointing at first data elt */
+  gint *dims;			/* pointer to int containing # of dimensions */
+  gint **index_min;		/* pointer^2 to intv containing min indices, by dim */
+  gint **index_sizes;		/* pointer^2 to intv containing size, by dim */
+  gint **strides;		/* pointer^2 to intv of strides, by dim */
+  double **data;		/* pointer^2 pointing at first data elt */
 };
 
-struct _GuppiArrayImplClass {
+typedef struct {
   GuppiDataImplClass parent_class;
 
   /* Virtual functions/variables */
-  void (*construct)(GuppiArrayImpl*, gint, const gint*, const gint*);
-  void (*get_cb)(const GuppiArrayImpl*, const gint*);
-  void (*set_cb)(GuppiArrayImpl*, double x, const gint*);
-};
+  void (*construct) (GuppiArrayImpl *, gint, const gint *, const gint *);
+  void (*get_cb) (const GuppiArrayImpl *, const gint *);
+  void (*set_cb) (GuppiArrayImpl *, double x, const gint *);
+} GuppiArrayImplClass;
 
 #define GUPPI_TYPE_ARRAY_IMPL (guppi_array_impl_get_type())
 #define GUPPI_ARRAY_IMPL(obj) (GTK_CHECK_CAST((obj),GUPPI_TYPE_ARRAY_IMPL,GuppiArrayImpl))
@@ -64,21 +66,10 @@ struct _GuppiArrayImplClass {
 #define GUPPI_IS_ARRAY_IMPL0(obj) (((obj) == NULL) || (GUPPI_IS_ARRAY_IMPL(obj)))
 #define GUPPI_IS_ARRAY_IMPL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_ARRAY_IMPL))
 
-GtkType guppi_array_impl_get_type(void);
+GtkType guppi_array_impl_get_type (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ARRAY_IMPL_H */
 
-/* $Id: guppi-array-impl.h,v 1.2 2000/04/13 19:45:19 trow Exp $ */
-
-
-
-
-
-
-
-
-
-
-
-
-
+/* $Id: guppi-array-impl.h,v 1.8 2000/10/27 18:22:58 trow Exp $ */
