@@ -32,11 +32,14 @@
 
 #include <math.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
 #include "guppi-equation.h"
 
 extern FILE* yyin;
 extern char* yytext;
 extern int yylex();
+void yyerror(char* s);
 
 #define YYSTYPE GuppiEquation*
 
@@ -113,9 +116,9 @@ static const short yyrhs[] = {    27,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    38,    41,    45,    49,    53,    57,    62,    66,    70,    74,
-    78,    82,    86,    90,    94,    98,   102,   106,   110,   114,
-   118
+    41,    44,    48,    52,    56,    60,    65,    69,    73,    77,
+    81,    85,    89,    93,    97,   101,   105,   109,   113,   117,
+   121
 };
 #endif
 
@@ -732,126 +735,126 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 39 "guppi-equation-parser.y"
+#line 42 "guppi-equation-parser.y"
 { return yyvsp[-1]; ;
     break;}
 case 2:
-#line 42 "guppi-equation-parser.y"
+#line 45 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_constant(atof(yytext));
 ;
     break;}
 case 3:
-#line 46 "guppi-equation-parser.y"
+#line 49 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_constant(-atof(yytext));
 ;
     break;}
 case 4:
-#line 50 "guppi-equation-parser.y"
+#line 53 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_constant(M_PI);
 ;
     break;}
 case 5:
-#line 54 "guppi-equation-parser.y"
+#line 57 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_constant(M_E);
 ;
     break;}
 case 6:
-#line 58 "guppi-equation-parser.y"
+#line 61 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_variable_subscripted(last_variable,
                                            atoi(yytext+1));
 ;
     break;}
 case 7:
-#line 63 "guppi-equation-parser.y"
+#line 66 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_variable(last_variable);
 ;
     break;}
 case 8:
-#line 67 "guppi-equation-parser.y"
+#line 70 "guppi-equation-parser.y"
 {
   yyval = yyvsp[-1];
 ;
     break;}
 case 9:
-#line 71 "guppi-equation-parser.y"
+#line 74 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_binary(EQN_SUM, yyvsp[-2], yyvsp[0]);
 ;
     break;}
 case 10:
-#line 75 "guppi-equation-parser.y"
+#line 78 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_binary(EQN_DIFFERENCE, yyvsp[-2], yyvsp[0]);
 ;
     break;}
 case 11:
-#line 79 "guppi-equation-parser.y"
+#line 82 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_binary(EQN_PRODUCT, yyvsp[-2], yyvsp[0]);
 ;
     break;}
 case 12:
-#line 83 "guppi-equation-parser.y"
+#line 86 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_binary(EQN_QUOTIENT, yyvsp[-2], yyvsp[0]);
 ;
     break;}
 case 13:
-#line 87 "guppi-equation-parser.y"
+#line 90 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_binary(EQN_POW, yyvsp[-2], yyvsp[0]);
 ;
     break;}
 case 14:
-#line 91 "guppi-equation-parser.y"
+#line 94 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_unary(EQN_SIN, yyvsp[0]);
 ;
     break;}
 case 15:
-#line 95 "guppi-equation-parser.y"
+#line 98 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_unary(EQN_COS, yyvsp[0]);
 ;
     break;}
 case 16:
-#line 99 "guppi-equation-parser.y"
+#line 102 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_unary(EQN_TAN, yyvsp[0]);
 ;
     break;}
 case 17:
-#line 103 "guppi-equation-parser.y"
+#line 106 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_unary(EQN_EXP, yyvsp[0]);
 ;
     break;}
 case 18:
-#line 107 "guppi-equation-parser.y"
+#line 110 "guppi-equation-parser.y"
 { 
   yyval = guppi_equation_unary(EQN_LOG, yyvsp[0]);
 ;
     break;}
 case 19:
-#line 111 "guppi-equation-parser.y"
+#line 114 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_unary(EQN_LOG10, yyvsp[0]);
 ;
     break;}
 case 20:
-#line 115 "guppi-equation-parser.y"
+#line 118 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_cpow(yyvsp[0], 2);
 ;
     break;}
 case 21:
-#line 119 "guppi-equation-parser.y"
+#line 122 "guppi-equation-parser.y"
 {
   yyval = guppi_equation_cpow(yyvsp[0], 0.5);
 ;
@@ -1078,7 +1081,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 125 "guppi-equation-parser.y"
+#line 128 "guppi-equation-parser.y"
 
 
 void yyerror(char* s)
