@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-alpha-template.h,v 1.2 2000/04/11 02:48:52 trow Exp $ */
+/* $Id: guppi-alpha-template.h,v 1.7 2000/10/27 18:23:00 trow Exp $ */
 
 /*
  * guppi-alpha-template.h
@@ -28,18 +28,22 @@
 #ifndef _INC_GUPPI_ALPHA_TEMPLATE_H
 #define _INC_GUPPI_ALPHA_TEMPLATE_H
 
-#include <config.h>
 #include <gnome.h>
 #include <libgnomeprint/gnome-font.h>
 
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
+
 typedef struct _GuppiAlphaTemplate GuppiAlphaTemplate;
 typedef struct _GuppiAlphaTemplateClass GuppiAlphaTemplateClass;
 
 struct _GuppiAlphaTemplate {
   GtkObject parent;
 
+  gint x_offset, y_offset;
   gint width, height;
-  guchar* data;
+  guchar *data;
 };
 
 struct _GuppiAlphaTemplateClass {
@@ -54,24 +58,23 @@ struct _GuppiAlphaTemplateClass {
 #define GUPPI_IS_ALPHA_TEMPLATE0(obj) (((obj) == NULL) || (GUPPI_IS_ALPHA_TEMPLATE(obj)))
 #define GUPPI_IS_ALPHA_TEMPLATE_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_ALPHA_TEMPLATE))
 
-GtkType guppi_alpha_template_get_type(void);
+GtkType guppi_alpha_template_get_type (void);
 
-GuppiAlphaTemplate* guppi_alpha_template_new(gint w, gint h);
+GuppiAlphaTemplate *guppi_alpha_template_new (gint w, gint h);
 
-guchar guppi_alpha_template_get(GuppiAlphaTemplate*, gint x, gint y);
-void guppi_alpha_template_set(GuppiAlphaTemplate*, gint x, gint y, guchar a);
+guchar guppi_alpha_template_get (GuppiAlphaTemplate *, gint x, gint y);
+void guppi_alpha_template_set (GuppiAlphaTemplate *, gint x, gint y,
+			       guchar a);
 
-void guppi_alpha_template_print(GuppiAlphaTemplate*,
-				gint x, gint y,
-				guchar r, guchar g, guchar b, guchar a,
-				guchar* rgbbuf, gint buf_stride,
-				gint buf_w, gint buf_h,
-				gint adj_x, gint adj_y);
+void guppi_alpha_template_print (GuppiAlphaTemplate *,
+				 gint x, gint y,
+				 guint r, guint g, guint b, guint a,
+				 GnomeCanvasBuf *);
 
-GuppiAlphaTemplate* guppi_alpha_template_copy_rectangle(GuppiAlphaTemplate*,
-							gint x, gint y,
-							gint w, gint h);
-void guppi_alpha_template_auto_crop(GuppiAlphaTemplate*);
+GuppiAlphaTemplate *guppi_alpha_template_copy_rectangle (GuppiAlphaTemplate *,
+							 gint x, gint y,
+							 gint w, gint h);
+void guppi_alpha_template_auto_crop (GuppiAlphaTemplate *);
 
 #define guppi_alpha_template_get_unsafe(atemp, x, y) \
 ((atemp)->data[(atemp)->width * (y) + (x)])
@@ -79,32 +82,34 @@ void guppi_alpha_template_auto_crop(GuppiAlphaTemplate*);
 #define guppi_alpha_template_set_unsafe(atemp, x, y, val) \
 ((atemp)->data[(atemp)->width * (y) + (x)] = val)
 
-GuppiAlphaTemplate* guppi_alpha_template_new_frame(gint w, gint h);
-GuppiAlphaTemplate* guppi_alpha_template_new_circle(double r);
-GuppiAlphaTemplate* guppi_alpha_template_new_ring(double r, double w);
-GuppiAlphaTemplate* guppi_alpha_template_new_cross(double r, double w,
-						   double theta);
-GuppiAlphaTemplate* guppi_alpha_template_new_ast(double r, double w,
-						 double theta);
-GuppiAlphaTemplate* guppi_alpha_template_new_rectangle(double r, double w,
-						       double theta);
-GuppiAlphaTemplate* guppi_alpha_template_new_box(double r, double th);
+GuppiAlphaTemplate *guppi_alpha_template_new_frame (gint w, gint h);
+GuppiAlphaTemplate *guppi_alpha_template_new_circle (double r);
+GuppiAlphaTemplate *guppi_alpha_template_new_ring (double r, double w);
+GuppiAlphaTemplate *guppi_alpha_template_new_cross (double r, double w,
+						    double theta);
+GuppiAlphaTemplate *guppi_alpha_template_new_ast (double r, double w,
+						  double theta);
+GuppiAlphaTemplate *guppi_alpha_template_new_rectangle (double r, double w,
+							double theta);
+GuppiAlphaTemplate *guppi_alpha_template_new_box (double r, double th);
 
-GuppiAlphaTemplate* guppi_alpha_template_text_general(GnomeFont* font,
-						      double size,
-						      const gchar* text,
-						      double rot_angle,
-						      gboolean filled,
-						      double outline_width);
-#define guppi_alpha_template_text(font,size,text) \
-  guppi_alpha_template_text_general((font),(size),(text),0,TRUE,0)
+GuppiAlphaTemplate *guppi_alpha_template_text_general (GnomeFont * font,
+						       double scale,
+						       const gchar * text,
+						       double rot_angle,
+						       gboolean filled,
+						       double outline_width);
+#define guppi_alpha_template_text(font,text) \
+  guppi_alpha_template_text_general((font),1.0,(text),0,TRUE,0)
 
-#define guppi_alpha_template_outline_text(font,size,text,width) \
-  guppi_alpha_template_text_general((font),(size),(text),0,FALSE,(width))
+#define guppi_alpha_template_outline_text(font,text,width) \
+  guppi_alpha_template_text_general((font),1.0,(text),0,FALSE,(width))
 
 
 
 
+END_GUPPI_DECLS
+
 #endif /* _INC_GUPPI_ALPHA_TEMPLATE_H */
 
-/* $Id: guppi-alpha-template.h,v 1.2 2000/04/11 02:48:52 trow Exp $ */
+/* $Id: guppi-alpha-template.h,v 1.7 2000/10/27 18:23:00 trow Exp $ */
