@@ -1,4 +1,4 @@
-/* $Id: guppi-plot-init.c,v 1.1 2000/02/18 05:09:52 trow Exp $ */
+/* $Id: guppi-plot-init.c,v 1.5 2000/10/20 01:21:47 trow Exp $ */
 
 /*
  * guppi-plot-init.c
@@ -24,18 +24,29 @@
  * USA
  */
 
+#include <config.h>
+#include <guppi-guile.h>
 #include "guppi-plot-init.h"
 #include "guppi-scm-plot.h"
 
+#ifdef HAVE_PYTHON
+#include "guppi-python-plot.h"
+#endif
+
 void
-guppi_plot_init(void)
+guppi_plot_init (void)
 {
   static gboolean inited = FALSE;
-  g_return_if_fail(inited == FALSE);
+  g_return_if_fail (inited == FALSE);
   inited = TRUE;
 
-  guppi_scm_plot_init();
+  if (guppi_guile_is_active ())
+    guppi_scm_plot_init ();
+
+#ifdef HAVE_PYTHON
+  guppi_python_plot_init ();
+#endif
 }
 
 
-/* $Id: guppi-plot-init.c,v 1.1 2000/02/18 05:09:52 trow Exp $ */
+/* $Id: guppi-plot-init.c,v 1.5 2000/10/20 01:21:47 trow Exp $ */
