@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-tool.h,v 1.2 2000/03/04 18:52:51 trow Exp $ */
+/* $Id: guppi-plot-tool.h,v 1.13 2000/10/27 18:23:00 trow Exp $ */
 
 /*
  * guppi-plot-tool.h
@@ -28,14 +28,18 @@
 #ifndef _INC_GUPPI_PLOT_TOOL_H
 #define _INC_GUPPI_PLOT_TOOL_H
 
-#include <config.h>
 #include <gnome.h>
 
-#include "guppi-canvas-item.h"
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
+
+struct _GuppiCanvasItem;
 
 typedef enum {
   GPTPC_NONE,
   GPTPC_FRAME,
+  GPTPC_FRAME_BY_CENTER,
   GPTPC_CIRCLE
 } GuppiPlotToolPositionCue;
 
@@ -45,39 +49,55 @@ typedef struct _GuppiPlotToolClass GuppiPlotToolClass;
 struct _GuppiPlotTool {
   GtkObject parent;
 
-  gint tool_id;
-  const gchar* name;
-  GtkType acts_on;
+  gchar *name;
+  GtkType supported_type;
 
-  GdkCursor* cursor;
+  gint button;
+
+  GdkCursor *cursor;
 
   gboolean tracks_motion;
   GuppiPlotToolPositionCue cue_type;
   guint32 cue_fill_color;
   double cue_arg;
-  GnomeCanvasItem* cue_item;
+  GnomeCanvasItem *cue_item;
 
   gboolean repeating;
   gint repeat_interval;
 
-  double arg1, arg2;
-  gpointer arg3;
+  /* useful places to temporarily stuff data... */
+  gint int_arg1, int_arg2, int_arg3;
+  double arg1, arg2, arg3;
+  gpointer ptr_arg1, ptr_arg2, ptr_arg3;
 
+  /* Canvas coordinates */
   double raw_start_x, raw_start_y;
   double raw_prev_x, raw_prev_y;
   double raw_x, raw_y;
-  
+
+  /* vp coordinates */
   double start_x, start_y;
   double prev_x, prev_y;
-  double x, y; /* current x, y */
+  double x, y;			/* current x, y */
+
+  /* pt (device indep) coordinates */
+  double start_pt_x, start_pt_y;
+  double prev_pt_x, prev_pt_y;
+  double pt_x, pt_y;		/* current x, y */
+
   gint repeater_tag;
 
-  GuppiCanvasItem* canvas_item;
+  gboolean terminated;
 
-  void (*first)(GuppiPlotTool*, GuppiCanvasItem*);
-  void (*middle)(GuppiPlotTool*, GuppiCanvasItem*);
-  void (*repeat)(GuppiPlotTool*, GuppiCanvasItem*);
-  void (*last)(GuppiPlotTool*, GuppiCanvasItem*);
+  struct _GuppiCanvasItem *canvas_item;
+
+    gboolean (*supports) (GuppiPlotTool *, struct _GuppiCanvasItem *);
+  void (*first) (GuppiPlotTool *, struct _GuppiCanvasItem *);
+  void (*middle) (GuppiPlotTool *, struct _GuppiCanvasItem *);
+  void (*repeat) (GuppiPlotTool *, struct _GuppiCanvasItem *);
+  void (*last) (GuppiPlotTool *, struct _GuppiCanvasItem *);
+
+  void (*finalize) (GuppiPlotTool *);
 };
 
 struct _GuppiPlotToolClass {
@@ -92,24 +112,28 @@ struct _GuppiPlotToolClass {
 #define GUPPI_IS_PLOT_TOOL0(obj) (((obj) == NULL) || (GUPPI_IS_PLOT_TOOL(obj)))
 #define GUPPI_IS_PLOT_TOOL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_PLOT_TOOL))
 
-GtkType guppi_plot_tool_get_type(void);
-
-/* Returns assigned tool id */
-gint guppi_plot_tool_register(GuppiPlotTool*);
-
-GuppiPlotTool* guppi_plot_tool_new(void);
-GuppiPlotTool* guppi_plot_tool_new_by_id(gint);
-
-GuppiPlotTool* guppi_plot_tool_new_rescale(double scale);
-GuppiPlotTool* guppi_plot_tool_new_recenter(void);
-GuppiPlotTool* guppi_plot_tool_new_drag(void);
-GuppiPlotTool* guppi_plot_tool_new_reframe(void);
+GtkType guppi_plot_tool_get_type (void);
 
+GuppiPlotTool *guppi_plot_tool_new (void);
 
+const gchar *guppi_plot_tool_name (GuppiPlotTool *);
+void guppi_plot_tool_set_name (GuppiPlotTool * tool, const gchar *);
 
+gboolean guppi_plot_tool_supports_item (GuppiPlotTool *,
+					struct _GuppiCanvasItem *);
+
+void guppi_plot_tool_first (GuppiPlotTool *,
+			    struct _GuppiCanvasItem *,
+			    double c_x, double c_y);
+void guppi_plot_tool_middle (GuppiPlotTool *, double c_x, double c_y);
+void guppi_plot_tool_end (GuppiPlotTool *, double c_x, double c_y);
+
+/* Return an (allegedly) unique id for each type of tool. */
+guint guppi_plot_tool_signature (GuppiPlotTool *);
 
 
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PLOT_TOOL_H */
 
-/* $Id: guppi-plot-tool.h,v 1.2 2000/03/04 18:52:51 trow Exp $ */
+/* $Id: guppi-plot-tool.h,v 1.13 2000/10/27 18:23:00 trow Exp $ */
