@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-window.h,v 1.2 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-plot-window.h,v 1.12 2000/10/27 18:23:00 trow Exp $ */
 
 /*
  * guppi-plot-window.h
@@ -28,9 +28,14 @@
 #ifndef _INC_GUPPI_PLOT_WINDOW_H
 #define _INC_GUPPI_PLOT_WINDOW_H
 
-#include <config.h>
 #include <gnome.h>
-#include <guppi-plot-view.h>
+#include "guppi-root-group-view.h"
+#include "guppi-root-group-item.h"
+#include "guppi-canvas-item.h"
+
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS 
 
 typedef struct _GuppiPlotWindow GuppiPlotWindow;
 typedef struct _GuppiPlotWindowClass GuppiPlotWindowClass;
@@ -38,8 +43,18 @@ typedef struct _GuppiPlotWindowClass GuppiPlotWindowClass;
 struct _GuppiPlotWindow {
   GnomeApp parent;
 
-  GuppiPlotView* view;
-  GnomeAppBar* status_bar;
+  GtkToolbar *toolbar;
+  GtkCombo *zoom_combo;
+  GnomeAppBar *status_bar;
+
+#if 0
+  GuppiProperties *properties;
+  GtkWidget *properties_window;
+#endif
+
+  GnomeCanvas *canv;
+  GuppiRootGroupView *root_view;
+  GuppiRootGroupItem *root_item;
 };
 
 struct _GuppiPlotWindowClass {
@@ -52,14 +67,13 @@ struct _GuppiPlotWindowClass {
 #define GUPPI_IS_PLOT_WINDOW(obj) (GTK_CHECK_TYPE((obj), GUPPI_TYPE_PLOT_WINDOW))
 #define GUPPI_IS_PLOT_WINDOW_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_PLOT_WINDOW))
 
-GtkType guppi_plot_window_get_type(void);
-
-void guppi_plot_window_construct(GuppiPlotWindow*, GuppiPlotState*);
-GtkWidget* guppi_plot_window_new(GuppiPlotState*);
-
+GtkType guppi_plot_window_get_type (void);
 
+void guppi_plot_window_construct (GuppiPlotWindow *, GuppiRootGroupView *);
+GtkWidget *guppi_plot_window_new (GuppiRootGroupView * root_view);
 
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PLOT_WINDOW_H */
 
-/* $Id: guppi-plot-window.h,v 1.2 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-plot-window.h,v 1.12 2000/10/27 18:23:00 trow Exp $ */
