@@ -1,4 +1,4 @@
-/* $Id: guppi-defaults.h,v 1.1 2000/04/13 19:45:21 trow Exp $ */
+/* $Id: guppi-defaults.h,v 1.8 2000/10/27 18:23:05 trow Exp $ */
 
 /*
  * guppi-defaults.h
@@ -27,17 +27,31 @@
 #ifndef _INC_GUPPI_DEFAULTS_H
 #define _INC_GUPPI_DEFAULTS_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <libgnomeprint/gnome-font.h>
+#include "guppi-metrics.h"
+
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
 
 /* Someday I'll use gconf for this.  Until then, I'm just encapsulating
    this information in the simplest way possible... */
+  GnomeFont * guppi_default_font_large (void);
+GnomeFont *guppi_default_font_medium (void);
+GnomeFont *guppi_default_font_small (void);
 
-GnomeFont* guppi_default_font(void);
-double guppi_default_axis_label_size(void);
-double guppi_default_plot_label_size(void);
+GnomeFont *guppi_default_font (void);	/* same as guppi_default_font_medium() */
+
+/* ugly ugly ugly */
+double guppi_default_axis_label_size (void);
+double guppi_default_plot_label_size (void);
+
+
+guppi_metric_t guppi_default_units (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DEFAULTS_H */
 
-/* $Id: guppi-defaults.h,v 1.1 2000/04/13 19:45:21 trow Exp $ */
+/* $Id: guppi-defaults.h,v 1.8 2000/10/27 18:23:05 trow Exp $ */
