@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-garray.h,v 1.2 2000/04/13 19:45:22 trow Exp $ */
+/* $Id: guppi-garray.h,v 1.9 2000/11/12 04:18:20 trow Exp $ */
 
 /*
  * guppi-garray.h
@@ -28,8 +28,10 @@
 #ifndef _INC_GUPPI_GARRAY_H
 #define _INC_GUPPI_GARRAY_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
 
 typedef struct _GuppiGArray GuppiGArray;
 typedef struct _GuppiGArrayClass GuppiGArrayClass;
@@ -42,7 +44,12 @@ typedef struct _GuppiGArrayClass GuppiGArrayClass;
 struct _GuppiGArray {
   GtkObject parent;
 
-  GArray* array;
+  gsize size;
+  gsize el_size;
+  gpointer data;
+#if 0
+  GArray *array;
+#endif
 };
 
 struct _GuppiGArrayClass {
@@ -57,11 +64,12 @@ struct _GuppiGArrayClass {
 #define GUPPI_IS_GARRAY0(obj) (((obj) == NULL) || (GUPPI_IS_GARRAY(obj)))
 #define GUPPI_IS_GARRAY_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_GARRAY))
 
-GtkType guppi_garray_get_type(void);
+GtkType guppi_garray_get_type (void);
 
-void guppi_garray_construct(GuppiGArray* ga, guint element_size);
-GuppiGArray* guppi_garray_new(guint element_size);
+void guppi_garray_construct (GuppiGArray * ga, guint element_size);
+GuppiGArray *guppi_garray_new (guint element_size);
 
+#if 0
 #define guppi_garray_data(ga) ((ga)->array->data)
 #define guppi_garray_size(ga) ((ga)->array->len)
 #define guppi_garray_element_size(ga) (((GRealArray*)((ga)->array))->elt_size)
@@ -71,10 +79,15 @@ GuppiGArray* guppi_garray_new(guint element_size);
 #define guppi_garray_insert_vals(ga, i, ptr, len) (g_array_insert_vals((ga)->array, i, ptr, len), (ga))
 #define guppi_garray_set_size(ga, len) (g_array_set_size((ga)->array, len), (ga))
 #define guppi_garray_remove_index(ga, i) (g_array_remove_index((ga)->array, i), (ga))
+#endif
 
+#define guppi_garray_data(ga) ((ga)->data)
+#define guppi_garray_size(ga) ((ga)->size)
+#define guppi_garray_element_size(ga) ((ga)->el_size)
+void guppi_garray_set_size (GuppiGArray *, gsize);
 
-
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_GARRAY_H */
 
-/* $Id: guppi-garray.h,v 1.2 2000/04/13 19:45:22 trow Exp $ */
+/* $Id: guppi-garray.h,v 1.9 2000/11/12 04:18:20 trow Exp $ */
