@@ -1,4 +1,4 @@
-/* $Id: guppi-paths.h,v 1.3 2000/04/06 23:27:32 trow Exp $ */
+/* $Id: guppi-paths.h,v 1.12 2000/12/16 03:42:50 trow Exp $ */
 
 /*
  * guppi-paths.h
@@ -27,13 +27,32 @@
 #ifndef _INC_GUPPI_PATHS_H
 #define _INC_GUPPI_PATHS_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-const gchar* guppi_logo_graphic_path(void);
-const gchar* guppi_glade_path(const gchar* filename);
-const gchar* gnome_guile_repl_path(void);
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
+
+void force_development_path_hacks (void);
+gboolean development_path_hacks (void);
+
+void guppi_pixmap_path_add (const gchar * path);
+gchar *guppi_find_pixmap (const gchar * filename);
+const gchar *guppi_logo_graphic_path (void);
+
+void guppi_script_path_add (const gchar * path);
+gchar *guppi_find_script (const gchar * filename);
+gchar *guppi_find_guile_script (const gchar * filename); /* historical... */
+
+void guppi_glade_path_add (const gchar * filename);
+const gchar *guppi_glade_path (const gchar * filename);
+
+const gchar *gnome_guile_repl_path (void);
+
+void guppi_paths_init (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PATHS_H */
 
-/* $Id: guppi-paths.h,v 1.3 2000/04/06 23:27:32 trow Exp $ */
+/* $Id: guppi-paths.h,v 1.12 2000/12/16 03:42:50 trow Exp $ */
