@@ -1,4 +1,4 @@
-/* $Id: guppi-progress.h,v 1.1 2000/03/04 18:48:21 trow Exp $ */
+/* $Id: guppi-progress.h,v 1.6 2000/10/27 18:23:05 trow Exp $ */
 
 /*
  * guppi-progress.h
@@ -27,16 +27,21 @@
 #ifndef _INC_GUPPI_PROGRESS_H
 #define _INC_GUPPI_PROGRESS_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-void guppi_progress_register(GtkProgress* progress);
+#include <guppi-defs.h>
 
-void guppi_progress_set_percentage(float x);
-void guppi_progress_show_activity(void);
+BEGIN_GUPPI_DECLS 
 
-void guppi_progress_clear(void);
+void guppi_progress_register (GtkProgress * progress);
+
+void guppi_progress_set_percentage (float x);
+void guppi_progress_show_activity (void);
+
+void guppi_progress_clear (void);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PROGRESS_H */
 
-/* $Id: guppi-progress.h,v 1.1 2000/03/04 18:48:21 trow Exp $ */
+/* $Id: guppi-progress.h,v 1.6 2000/10/27 18:23:05 trow Exp $ */
