@@ -1,4 +1,4 @@
-/* $Id: guppi-splash.h,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-splash.h,v 1.9 2000/10/27 18:23:05 trow Exp $ */
 
 /*
  * guppi-splash.h
@@ -27,14 +27,19 @@
 #ifndef _INC_GUPPI_SPLASH_H
 #define _INC_GUPPI_SPLASH_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-void guppi_splash_create(void);
-void guppi_splash_destroy(void);
-void guppi_splash_message(const gchar*);
+#include <guppi-defs.h>
 
+BEGIN_GUPPI_DECLS
+
+void guppi_splash_text (void);
+void guppi_splash_create (void);
+void guppi_splash_destroy (void);
+void guppi_splash_message (const gchar * line1, const gchar * line2);
+
+END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SPLASH_H */
 
-/* $Id: guppi-splash.h,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-splash.h,v 1.9 2000/10/27 18:23:05 trow Exp $ */
