@@ -22,22 +22,54 @@
  * USA
  */
 
+#include <config.h>
+#include <gnan.h>
 #include "guppi-useful.h"
+#include "guppi-dharma.h"
 #include "guppi-scm-useful.h"
 
+#ifdef HAVE_PYTHON
+#include "guppi-python-useful.h"
+#include "guppi-python.h"
+#endif
+
 void
-guppi_useful_init(void)
+guppi_useful_init (void)
 {
-  guppi_guile_init();
-  guppi_scm_useful_init();
+  guppi_guile_init ();
+  guppi_scm_useful_init ();
+  guppi_useful_init_without_guile ();
 
-  guppi_timer_init();
+}
 
-  /* Try to insure that we can't gracelessly shutdown the whole process
-     from guile. */
-  gh_eval_str("(define exit guppi-exit)");
+void
+guppi_useful_init_without_guile (void)
+{
+
+#ifdef HAVE_PYTHON
+  if (!guppi_python_is_active ()) {
+    guppi_python_init ();
+    guppi_python_useful_init ();
+  }
+#endif
+
+  gnan_init ();
+  guppi_timer_init ();
+  guppi_dharma_init ();
+  guppi_paths_init ();
+
+  guppi_plug_in_path_reset_to_default ();
+
+  if (guppi_guile_is_active ()) {
+    /* Try to insure that we can't gracelessly shutdown the whole process
+       from guile. */
+    gh_eval_str ("(define exit guppi-exit)");
+  }
+
+  guppi_exit_connect_shutdown_func (guppi_plug_in_spec_shutdown,
+				    NULL, "Clean up Plug-In Cache");
 }
 
 
 
-/* $Id: guppi-useful.c,v 1.4 2000/02/22 19:39:30 trow Exp $ */
+/* $Id: guppi-useful.c,v 1.16 2000/12/16 03:42:51 trow Exp $ */
