@@ -1,4 +1,4 @@
-/* $Id: guppi-version.c,v 1.1 2000/02/10 02:07:40 trow Exp $ */
+/* $Id: guppi-version.c,v 1.8 2000/10/20 01:21:56 trow Exp $ */
 
 /*
  * guppi-version.c
@@ -24,31 +24,78 @@
  * USA
  */
 
+#include <config.h>
 #include "guppi-version.h"
 
-const gchar*
-guppi_version(void)
+const gchar *
+guppi_version (void)
 {
   return VERSION;
 }
 
 gint
-guppi_version_major(void)
+guppi_version_major (void)
 {
   return GUPPI_MAJOR_VERSION;
 }
 
 gint
-guppi_version_minor(void)
+guppi_version_minor (void)
 {
   return GUPPI_MINOR_VERSION;
 }
 
 gint
-guppi_version_micro(void)
+guppi_version_micro (void)
 {
   return GUPPI_MICRO_VERSION;
 }
 
+const gchar *
+guppi_copyright (void)
+{
+  return "Copyright (C) 1999-2000 EMC Capital Management, Inc.";
+}
 
-/* $Id: guppi-version.c,v 1.1 2000/02/10 02:07:40 trow Exp $ */
+const gchar **
+guppi_developers (void)
+{
+  static const gchar *developers[] = {
+    "Jon Trowbridge",
+    "Havoc Pennington",
+    "Andrew Chatham",
+    "Jody Goldberg",
+    "Michael Meeks",
+    "Morten Welinder",
+    NULL
+  };
+
+  return developers;
+}
+
+const gchar **
+guppi_helpers (void)
+{
+  static const gchar *helpers[] = {
+    "Kenny Graunke",
+    "Conrad Steenberg",
+    "Cesar Talon",
+    "Keld Simonsen",
+    "Kai Lahmann",
+    "Jean Brefort",
+    "Martin Quinson",
+    "Halldr rn lafsson",
+    "Jos Dehaes",
+    "Kjartan Maraas",
+    "Valek Filippov",
+    "Yuri Syrota",
+    "Andreas Hyden",
+    "Stephen L. Moshier",
+    NULL
+  };
+
+  return helpers;
+}
+
+
+/* $Id: guppi-version.c,v 1.8 2000/10/20 01:21:56 trow Exp $ */
