@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-version.h,v 1.1 2000/02/10 02:07:40 trow Exp $ */
+/* $Id: guppi-version.h,v 1.8 2000/10/27 18:23:05 trow Exp $ */
 
 /*
  * guppi-version.h
@@ -28,21 +28,29 @@
 #ifndef _INC_GUPPI_VERSION_H
 #define _INC_GUPPI_VERSION_H
 
-#include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+
+#include <guppi-defs.h>
+
+BEGIN_GUPPI_DECLS
 
 /*
   We functionalize this stuff (which is, of course, available in
   preprocessor symbols) so that we can automatically create alternative
   language bindings.
 */
+const gchar *guppi_version (void);
+gint guppi_version_major (void);
+gint guppi_version_minor (void);
+gint guppi_version_micro (void);
 
-const gchar* guppi_version(void);
-gint guppi_version_major(void);
-gint guppi_version_minor(void);
-gint guppi_version_micro(void);
+const gchar *guppi_copyright (void);
+const gchar **guppi_developers (void);
+const gchar **guppi_helpers (void);
 
 
+END_GUPPI_DECLS
+
 #endif /* _INC_GUPPI_VERSION_H */
 
-/* $Id: guppi-version.h,v 1.1 2000/02/10 02:07:40 trow Exp $ */
+/* $Id: guppi-version.h,v 1.8 2000/10/27 18:23:05 trow Exp $ */
